@@ -1,8 +1,8 @@
 import cupy as cp
-from pygpe.spinone.wavefunction import Wavefunction
+from pygpe.spinone.wavefunction import SpinOneWavefunction
 
 
-def step_wavefunction(wfn: Wavefunction, params: dict) -> None:
+def step_wavefunction(wfn: SpinOneWavefunction, params: dict) -> None:
     """Propagates the wavefunction forward one time step.
 
     :param wfn: The wavefunction of the system.
@@ -19,7 +19,7 @@ def step_wavefunction(wfn: Wavefunction, params: dict) -> None:
         _renormalise_wavefunction(wfn)
 
 
-def _kinetic_zeeman_step(wfn: Wavefunction, pm: dict) -> None:
+def _kinetic_zeeman_step(wfn: SpinOneWavefunction, pm: dict) -> None:
     """Computes the kinetic-zeeman subsystem for half a time step.
 
     :param wfn: The wavefunction of the system.
@@ -28,13 +28,15 @@ def _kinetic_zeeman_step(wfn: Wavefunction, pm: dict) -> None:
     wfn.fourier_plus_component *= cp.exp(
         -0.25 * 1j * pm["dt"] * (wfn.grid.wave_number + 2 * pm["q"])
     )
-    wfn.fourier_zero_component *= cp.exp(-0.25 * 1j * pm["dt"] * wfn.grid.wave_number)
+    wfn.fourier_zero_component *= cp.exp(
+        -0.25 * 1j * pm["dt"] * wfn.grid.wave_number
+    )
     wfn.fourier_minus_component *= cp.exp(
         -0.25 * 1j * pm["dt"] * (wfn.grid.wave_number + 2 * pm["q"])
     )
 
 
-def _interaction_step(wfn: Wavefunction, pm: dict) -> None:
+def _interaction_step(wfn: SpinOneWavefunction, pm: dict) -> None:
     """Computes the interaction subsystem for a full time step.
 
     :param wfn: The wavefunction of the system.
@@ -53,10 +55,12 @@ def _interaction_step(wfn: Wavefunction, pm: dict) -> None:
         + cp.conj(spin_perp) / cp.sqrt(2) * wfn.zero_component
     )
     zero_comp_temp = cos_term * wfn.zero_component - sin_term / cp.sqrt(2) * (
-        spin_perp * wfn.plus_component + cp.conj(spin_perp) * wfn.minus_component
+        spin_perp * wfn.plus_component
+        + cp.conj(spin_perp) * wfn.minus_component
     )
     minus_comp_temp = cos_term * wfn.minus_component - sin_term * (
-        spin_perp / cp.sqrt(2) * wfn.zero_component - spin_z * wfn.minus_component
+        spin_perp / cp.sqrt(2) * wfn.zero_component
+        - spin_z * wfn.minus_component
     )
 
     wfn.plus_component = plus_comp_temp * cp.exp(
@@ -70,7 +74,9 @@ def _interaction_step(wfn: Wavefunction, pm: dict) -> None:
     )
 
 
-def _calculate_spins(wfn: Wavefunction) -> tuple[cp.ndarray, cp.ndarray]:
+def _calculate_spins(
+    wfn: SpinOneWavefunction,
+) -> tuple[cp.ndarray, cp.ndarray]:
     """Calculates the perpendicular and longitudinal spins.
 
     :param wfn: The wavefunction of the system.
@@ -85,7 +91,7 @@ def _calculate_spins(wfn: Wavefunction) -> tuple[cp.ndarray, cp.ndarray]:
     return spin_perp, spin_z
 
 
-def _calculate_density(wfn: Wavefunction) -> cp.ndarray:
+def _calculate_density(wfn: SpinOneWavefunction) -> cp.ndarray:
     """Calculates the total condensate density.
 
     :param wfn: The wavefunction of the system.
@@ -98,7 +104,7 @@ def _calculate_density(wfn: Wavefunction) -> cp.ndarray:
     )
 
 
-def _renormalise_wavefunction(wfn: Wavefunction) -> None:
+def _renormalise_wavefunction(wfn: SpinOneWavefunction) -> None:
     """Re-normalises the wavefunction to the correct atom number.
 
     :param wfn: The wavefunction of the system.
@@ -109,18 +115,23 @@ def _renormalise_wavefunction(wfn: Wavefunction) -> None:
         wfn.atom_num_zero,
         wfn.atom_num_minus,
     )
-    current_atom_plus, current_atom_zero, current_atom_minus = _calculate_atom_num(wfn)
+    (
+        current_atom_plus,
+        current_atom_zero,
+        current_atom_minus,
+    ) = _calculate_atom_num(wfn)
     wfn.plus_component *= cp.sqrt(correct_atom_plus / current_atom_plus)
     wfn.zero_component *= cp.sqrt(correct_atom_zero / current_atom_zero)
     wfn.minus_component *= cp.sqrt(correct_atom_minus / current_atom_minus)
     wfn.fft()
 
 
-def _calculate_atom_num(wfn: Wavefunction) -> tuple[int, int, int]:
+def _calculate_atom_num(wfn: SpinOneWavefunction) -> tuple[int, int, int]:
     """Calculates the atom number of each wavefunction component.
 
     :param wfn: The wavefunction of the system.
-    :return: The atom numbers of the plus, zero, and minus components, respectively.
+    :return: The atom numbers of the plus, zero, and minus components,
+        respectively.
     """
     atom_num_plus = wfn.grid.grid_spacing_product * cp.sum(
         cp.abs(wfn.plus_component) ** 2
