@@ -1,11 +1,11 @@
 import h5py
 import cupy as cp
-from pygpe.shared.grid import Grid
+from pygpe.shared.data_manager import _DataManager
 from pygpe.shared import data_manager_paths as dmp
 from pygpe.spintwo.wavefunction import SpinTwoWavefunction
 
 
-class DataManager:
+class DataManager(_DataManager):
     """This object handles all the data of the simulation, including the
     wavefunction, grid, and parameter data.
 
@@ -18,59 +18,20 @@ class DataManager:
     :ivar data_path: The relative path to the folder containing the data file.
     """
 
-    def __init__(self, filename: str, data_path: str):
-        self.filename = filename
-        self.data_path = data_path
-        self._time_index = 0
-
-        # Create file
-        h5py.File(f"{self.data_path}/{self.filename}", "w")
-
-    def save_initial_parameters(
-        self, grid: Grid, wfn: SpinTwoWavefunction, parameters: dict
-    ) -> None:
-        """Saves the initial grid, wavefunction and parameters to a HDF5 file.
-
-        :param grid: The grid object of the system.
-        :type grid: :class:`Grid`
-        :param wfn: The wavefunction of the system.
-        :type wfn: :class:`Wavefunction`
-        :param parameters: The parameter dictionary.
-        :type parameters: dict
-        """
-        if grid.ndim > 3 or grid.ndim < 1:
-            raise ValueError(
-                f"Grid with dimension of {grid.ndim} is unsupported, "
-                "please use a 1D, 2D, or 3D grid."
-            )
-        self._save_initial_grid_params(grid)
+    def __init__(
+        self,
+        filename: str,
+        data_path: str,
+        wfn: SpinTwoWavefunction,
+        params: dict,
+    ):
+        """Constructs the DataManager object."""
+        super().__init__(filename, data_path, wfn, params)
         self._save_initial_wfn(wfn)
-        self._save_params(parameters)
-
-    def _save_initial_grid_params(self, grid: Grid) -> None:
-        """Creates new datasets in file for grid-related parameters and saves
-        initial values.
-        """
-        with h5py.File(f"{self.data_path}/{self.filename}", "r+") as file:
-            if grid.ndim == 1:
-                file.create_dataset(dmp.GRID_NX, data=grid.num_points_x)
-                file.create_dataset(dmp.GRID_DX, data=grid.grid_spacing_x)
-            elif grid.ndim == 2:
-                file.create_dataset(dmp.GRID_NX, data=grid.num_points_x)
-                file.create_dataset(dmp.GRID_NY, data=grid.num_points_y)
-                file.create_dataset(dmp.GRID_DX, data=grid.grid_spacing_x)
-                file.create_dataset(dmp.GRID_DY, data=grid.grid_spacing_y)
-            elif grid.ndim == 3:
-                file.create_dataset(dmp.GRID_NX, data=grid.num_points_x)
-                file.create_dataset(dmp.GRID_NY, data=grid.num_points_y)
-                file.create_dataset(dmp.GRID_NZ, data=grid.num_points_z)
-                file.create_dataset(dmp.GRID_DX, data=grid.grid_spacing_x)
-                file.create_dataset(dmp.GRID_DY, data=grid.grid_spacing_y)
-                file.create_dataset(dmp.GRID_DZ, data=grid.grid_spacing_z)
 
     def _save_initial_wfn(self, wfn: SpinTwoWavefunction) -> None:
         """Creates new datasets in file for the wavefunction."""
-        with h5py.File(f"{self.data_path}/{self.filename}", "r+") as file:
+        with h5py.File(self.data_path_and_file, "r+") as file:
             if wfn.grid.ndim == 1:
                 file.create_dataset(
                     dmp.SPIN2_WAVEFUNCTION_PLUS_TWO,
@@ -134,14 +95,6 @@ class DataManager:
                     dtype="complex128",
                 )
 
-    def _save_params(self, parameters: dict) -> None:
-        """Creates new datasets in file for condensate & time parameters
-        and saves initial values.
-        """
-        with h5py.File(f"{self.data_path}/{self.filename}", "r+") as file:
-            for key in parameters:
-                file.create_dataset(f"parameters/{key}", data=parameters[key])
-
     def save_wavefunction(self, wfn: SpinTwoWavefunction) -> None:
         """Saves the current wavefunction data to the dataset.
 
@@ -149,7 +102,7 @@ class DataManager:
         :type wfn: :class:`Wavefunction`
         """
         wfn.ifft()  # Update real-space wavefunction before saving
-        with h5py.File(f"{self.data_path}/{self.filename}", "r+") as data:
+        with h5py.File(self.data_path_and_file, "r+") as data:
             if wfn.grid.ndim == 1:
                 new_psi_plus2 = data[dmp.SPIN2_WAVEFUNCTION_PLUS_TWO]
                 new_psi_plus2.resize(
